==> zio-aws-dataexchange_2.13-5.17.129.2-sources.jar: zio/aws/dataexchange/model/DeleteEventActionRequest.scala <==
package zio.aws.dataexchange.model
import zio.aws.dataexchange.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeleteEventActionRequest(eventActionId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dataexchange.model.DeleteEventActionRequest = {
    import DeleteEventActionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dataexchange.model.DeleteEventActionRequest
      .builder()
      .eventActionId(__string.unwrap(eventActionId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.dataexchange.model.DeleteEventActionRequest.ReadOnly =
    zio.aws.dataexchange.model.DeleteEventActionRequest.wrap(buildAwsValue())
}
object DeleteEventActionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dataexchange.model.DeleteEventActionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.dataexchange.model.DeleteEventActionRequest =
      zio.aws.dataexchange.model.DeleteEventActionRequest(eventActionId)
    def eventActionId: __string
    def getEventActionId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(eventActionId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dataexchange.model.DeleteEventActionRequest
  ) extends zio.aws.dataexchange.model.DeleteEventActionRequest.ReadOnly {
    override val eventActionId: __string =
      zio.aws.dataexchange.model.primitives.__string(impl.eventActionId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.dataexchange.model.DeleteEventActionRequest
  ): zio.aws.dataexchange.model.DeleteEventActionRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-dataexchange_2.13-6.20.58.2-sources.jar: zio/aws/dataexchange/model/DeleteEventActionRequest.scala <==
package zio.aws.dataexchange.model
import zio.aws.dataexchange.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeleteEventActionRequest(eventActionId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dataexchange.model.DeleteEventActionRequest = {
    import DeleteEventActionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dataexchange.model.DeleteEventActionRequest
      .builder()
      .eventActionId(eventActionId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.dataexchange.model.DeleteEventActionRequest.ReadOnly =
    zio.aws.dataexchange.model.DeleteEventActionRequest.wrap(buildAwsValue())
}
object DeleteEventActionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dataexchange.model.DeleteEventActionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.dataexchange.model.DeleteEventActionRequest =
      zio.aws.dataexchange.model.DeleteEventActionRequest(eventActionId)
    def eventActionId: __string
    def getEventActionId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(eventActionId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dataexchange.model.DeleteEventActionRequest
  ) extends zio.aws.dataexchange.model.DeleteEventActionRequest.ReadOnly {
    override val eventActionId: __string = impl.eventActionId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.dataexchange.model.DeleteEventActionRequest
  ): zio.aws.dataexchange.model.DeleteEventActionRequest.ReadOnly = new Wrapper(
    impl
  )
}
